@@ -13,5 +13,3 @@ TRCVR_FILE = os.path.join(datadir, 'MWA_Trcvr_tile_56.csv')
 KNOWN_RFRB_CSV = os.path.join(datadir, 'known_repeating_FRBs.csv')
 POI_CSV = os.path.join(datadir, 'points_of_interest.csv')
 
-# Hard code the path of the ATNF psrcat database file
-ATNF_LOC = os.path.join(datadir, 'psrcat.db')
\ No newline at end of file
